package org.apache.bcel.generic;

import java.io.DataOutputStream;
import java.io.IOException;
import org.apache.bcel.classfile.ConstantDouble;
import org.apache.bcel.classfile.ConstantFloat;
import org.apache.bcel.classfile.ConstantInteger;
import org.apache.bcel.classfile.ConstantLong;
import org.apache.bcel.classfile.ConstantUtf8;
import org.apache.bcel.classfile.ElementValue;
import org.apache.bcel.classfile.SimpleElementValue;

/* loaded from: org_apache_bcel_generic.jar:org/apache/bcel/generic/SimpleElementValueGen.class */
public class SimpleElementValueGen extends ElementValueGen {
    private final int idx;

    public SimpleElementValueGen(int type, ConstantPoolGen cpGen, boolean value) {
        super(type, cpGen);
        if (value) {
            this.idx = getConstantPool().addInteger(1);
        } else {
            this.idx = getConstantPool().addInteger(0);
        }
    }

    public SimpleElementValueGen(int type, ConstantPoolGen cpGen, byte value) {
        super(type, cpGen);
        this.idx = getConstantPool().addInteger(value);
    }

    public SimpleElementValueGen(int type, ConstantPoolGen cpGen, char value) {
        super(type, cpGen);
        this.idx = getConstantPool().addInteger(value);
    }

    public SimpleElementValueGen(int type, ConstantPoolGen cpGen, double value) {
        super(type, cpGen);
        this.idx = getConstantPool().addDouble(value);
    }

    public SimpleElementValueGen(int type, ConstantPoolGen cpGen, float value) {
        super(type, cpGen);
        this.idx = getConstantPool().addFloat(value);
    }

    public SimpleElementValueGen(int type, ConstantPoolGen cpGen, int value) {
        super(type, cpGen);
        this.idx = getConstantPool().addInteger(value);
    }

    public SimpleElementValueGen(int type, ConstantPoolGen cpGen, long value) {
        super(type, cpGen);
        this.idx = getConstantPool().addLong(value);
    }

    public SimpleElementValueGen(int type, ConstantPoolGen cpGen, short value) {
        super(type, cpGen);
        this.idx = getConstantPool().addInteger(value);
    }

    public SimpleElementValueGen(int type, ConstantPoolGen cpGen, String value) {
        super(type, cpGen);
        this.idx = getConstantPool().addUtf8(value);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public SimpleElementValueGen(int type, int idx, ConstantPoolGen cpGen) {
        super(type, cpGen);
        this.idx = idx;
    }

    public SimpleElementValueGen(SimpleElementValue value, ConstantPoolGen cpool, boolean copyPoolEntries) {
        super(value.getElementValueType(), cpool);
        if (!copyPoolEntries) {
            this.idx = value.getIndex();
            return;
        }
        switch (value.getElementValueType()) {
            case ElementValueGen.PRIMITIVE_BYTE /* 66 */:
                this.idx = cpool.addInteger(value.getValueByte());
                return;
            case ElementValueGen.PRIMITIVE_CHAR /* 67 */:
                this.idx = cpool.addInteger(value.getValueChar());
                return;
            case ElementValueGen.PRIMITIVE_DOUBLE /* 68 */:
                this.idx = cpool.addDouble(value.getValueDouble());
                return;
            case ElementValueGen.PRIMITIVE_FLOAT /* 70 */:
                this.idx = cpool.addFloat(value.getValueFloat());
                return;
            case ElementValueGen.PRIMITIVE_INT /* 73 */:
                this.idx = cpool.addInteger(value.getValueInt());
                return;
            case ElementValueGen.PRIMITIVE_LONG /* 74 */:
                this.idx = cpool.addLong(value.getValueLong());
                return;
            case ElementValueGen.PRIMITIVE_SHORT /* 83 */:
                this.idx = cpool.addInteger(value.getValueShort());
                return;
            case ElementValueGen.PRIMITIVE_BOOLEAN /* 90 */:
                if (value.getValueBoolean()) {
                    this.idx = cpool.addInteger(1);
                    return;
                } else {
                    this.idx = cpool.addInteger(0);
                    return;
                }
            case ElementValueGen.STRING /* 115 */:
                this.idx = cpool.addUtf8(value.getValueString());
                return;
            default:
                throw new IllegalArgumentException("SimpleElementValueGen class does not know how to copy this type " + super.getElementValueType());
        }
    }

    @Override // org.apache.bcel.generic.ElementValueGen
    public void dump(DataOutputStream dos) throws IOException {
        dos.writeByte(super.getElementValueType());
        switch (super.getElementValueType()) {
            case ElementValueGen.PRIMITIVE_BYTE /* 66 */:
            case ElementValueGen.PRIMITIVE_CHAR /* 67 */:
            case ElementValueGen.PRIMITIVE_DOUBLE /* 68 */:
            case ElementValueGen.PRIMITIVE_FLOAT /* 70 */:
            case ElementValueGen.PRIMITIVE_INT /* 73 */:
            case ElementValueGen.PRIMITIVE_LONG /* 74 */:
            case ElementValueGen.PRIMITIVE_SHORT /* 83 */:
            case ElementValueGen.PRIMITIVE_BOOLEAN /* 90 */:
            case ElementValueGen.STRING /* 115 */:
                dos.writeShort(this.idx);
                return;
            default:
                throw new IllegalStateException("SimpleElementValueGen doesnt know how to write out type " + super.getElementValueType());
        }
    }

    @Override // org.apache.bcel.generic.ElementValueGen
    public ElementValue getElementValue() {
        return new SimpleElementValue(super.getElementValueType(), this.idx, getConstantPool().getConstantPool());
    }

    public int getIndex() {
        return this.idx;
    }

    public int getValueInt() {
        if (super.getElementValueType() != 73) {
            throw new IllegalStateException("Dont call getValueString() on a non STRING ElementValue");
        }
        ConstantInteger c = getConstantPool().getConstant(this.idx);
        return c.getBytes();
    }

    public String getValueString() {
        if (super.getElementValueType() != 115) {
            throw new IllegalStateException("Dont call getValueString() on a non STRING ElementValue");
        }
        ConstantUtf8 c = getConstantPool().getConstant(this.idx);
        return c.getBytes();
    }

    @Override // org.apache.bcel.generic.ElementValueGen
    public String stringifyValue() {
        switch (super.getElementValueType()) {
            case ElementValueGen.PRIMITIVE_BYTE /* 66 */:
                ConstantInteger b = getConstantPool().getConstant(this.idx);
                return Integer.toString(b.getBytes());
            case ElementValueGen.PRIMITIVE_CHAR /* 67 */:
                ConstantInteger ch = getConstantPool().getConstant(this.idx);
                return Integer.toString(ch.getBytes());
            case ElementValueGen.PRIMITIVE_DOUBLE /* 68 */:
                ConstantDouble d = getConstantPool().getConstant(this.idx);
                return Double.toString(d.getBytes());
            case ElementValueGen.PRIMITIVE_FLOAT /* 70 */:
                ConstantFloat f = getConstantPool().getConstant(this.idx);
                return Float.toString(f.getBytes());
            case ElementValueGen.PRIMITIVE_INT /* 73 */:
                ConstantInteger c = getConstantPool().getConstant(this.idx);
                return Integer.toString(c.getBytes());
            case ElementValueGen.PRIMITIVE_LONG /* 74 */:
                ConstantLong j = getConstantPool().getConstant(this.idx);
                return Long.toString(j.getBytes());
            case ElementValueGen.PRIMITIVE_SHORT /* 83 */:
                ConstantInteger s = getConstantPool().getConstant(this.idx);
                return Integer.toString(s.getBytes());
            case ElementValueGen.PRIMITIVE_BOOLEAN /* 90 */:
                ConstantInteger bo = getConstantPool().getConstant(this.idx);
                if (bo.getBytes() == 0) {
                    return "false";
                }
                return "true";
            case ElementValueGen.STRING /* 115 */:
                ConstantUtf8 cu8 = getConstantPool().getConstant(this.idx);
                return cu8.getBytes();
            default:
                throw new IllegalStateException("SimpleElementValueGen class does not know how to stringify type " + super.getElementValueType());
        }
    }
}
